SmfHookProtocol class abstract final

Single owner for hook environment names and JSON fields.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

androidReleaseField → const String
Nullable Android release JSON field.
androidStoreReleaseNotesCharacterLimit → const int
Google Play store-release-note character limit.
changeBodyField → const String
Conventional-change body JSON field.
changeDescriptionField → const String
Conventional-change description JSON field.
changeScopeField → const String
Conventional-change scope JSON field.
changesField → const String
Planned changes JSON field.
changeTypeField → const String
Conventional-change type JSON field.
contextPathEnvironment → const String
Environment variable containing the context JSON path.
iosReleaseField → const String
Nullable iOS release JSON field.
iosStoreReleaseNotesCharacterLimit → const int
Apple store-release-note character limit.
nextVersionField → const String
Planned next-version JSON field.
phaseField → const String
Hook-phase JSON field.
repositoryRootField → const String
Repository-root JSON field.
resultPathEnvironment → const String
Environment variable containing the completion JSON path.
schemaVersion → const int
Current wire schema.
schemaVersionField → const String
Schema-version JSON field.
secretNamesField → const String
Configured secret environment-name JSON field.
storeReleaseNotesFileField → const String
Store-release-notes file JSON field.