SmfHookProtocolPhase enum

Hook phase encoded by the engine.

Inheritance
Available extensions

Values

beforeCreatePr → const SmfHookProtocolPhase

Runs before creating or updating the release pull request.

const SmfHookProtocolPhase('before_create_pr')
beforeBuild → const SmfHookProtocolPhase

Runs before fingerprinting and building one store release candidate.

const SmfHookProtocolPhase('before_build')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Stable wire value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String value) → SmfHookProtocolPhase
Parses one exact wire value.

Constants

values → const List<SmfHookProtocolPhase>
A constant List of the values in this enum, in order of their declaration.